@@ -24,8 +24,10 @@ from urllib.parse import quote, unquote
 from flask import Response, make_response, redirect, render_template, request
 
 from rucio.common.config import config_get, config_get_bool
+from rucio.common.constants import DEFAULT_VO
 from rucio.common.exception import CannotAuthenticate
 from rucio.common.extra import import_extras
+from rucio.common.policy import get_policy
 from rucio.core import identity as identity_core
 from rucio.core import vo as vo_core
 from rucio.db.sqla.constants import AccountType, IdentityType
@@ -50,7 +52,7 @@ AUTH_TYPE = config_get('webui', 'auth_type', False, None)
 if AUTH_TYPE == 'oidc':
     try:
         AUTH_ISSUER_WEBUI = config_get('webui', 'auth_issuer')
-    except:
+    except Exception:
         render_template("problem.html", msg="Please specify auth_issuer in the [webui] section of the Rucio configuration.")
 
 # if no specific config on the server side - we collect information
@@ -64,7 +66,7 @@ if not AUTH_TYPE:
                 client_secrets = load(client_secret_file)
                 for iss in client_secrets:
                     AUTH_ISSUERS.append(iss.upper())
-    except:
+    except Exception:
         AUTH_ISSUERS = []
 
 # check if userpass login is enabled
@@ -143,7 +145,7 @@ def select_account_name(identitystr, identity_type, vo=None):
     """
     ui_account = None
     if not MULTI_VO:
-        vo = 'def'
+        vo = DEFAULT_VO
     if vo is not None:
         accounts = identity.list_accounts_for_identity(identitystr, identity_type)
     else:
@@ -174,7 +176,7 @@ def select_account_name(identitystr, identity_type, vo=None):
         # try to set the default account to the user account, if not available take the first account.
         def_account = accounts[0]
         for account in accounts:
-            account_info = get_account_info(account, vo=vo)
+            account_info = get_account_info(account, vo=vo or 'def')
             if account_info.account_type == AccountType.USER:
                 def_account = account
                 break
@@ -208,7 +210,7 @@ def get_token(token_method, acc=None, vo=None, idt=None, pwd=None):
         else:
             token = token_method(acc, idt, 'webui', request.environ.get('REMOTE_ADDR'), vo=vo).get('token')
         return token
-    except:
+    except Exception:
         return None
 
 
@@ -224,9 +226,11 @@ def validate_webui_token(from_cookie=True, session_token=None):
         session_token = request.cookies.get('x-rucio-auth-token')
     if session_token:
         session_token = unquote(session_token)
-    valid_token_dict = auth.validate_auth_token(session_token)
-    valid_token_dict['token'] = session_token  # pylint: disable=E1137
-    return valid_token_dict
+        valid_token_dict = auth.validate_auth_token(session_token)
+        valid_token_dict['token'] = session_token  # pylint: disable=E1137
+        return valid_token_dict
+    else:
+        raise CannotAuthenticate("No token found. Token must be either in cookies (with from_cookie=True) or provided separately.")
 
 
 def access_granted(valid_token_dict, template, title):
@@ -236,7 +240,7 @@ def access_granted(valid_token_dict, template, title):
     :param template: the template name that should be rendered
     :returns: rendered base temmplate with template content
     """
-    policy = config_get('policy', 'permission')
+    policy = get_policy()
     return render_template(template, token=valid_token_dict['token'], account=valid_token_dict['account'], vo=valid_token_dict['vo'], policy=policy, title=title)
 
 
@@ -306,7 +310,7 @@ def x509token_auth(data=None):
         return render_template("problem.html", msg="No certificate provided. Please authenticate with a certificate registered in Rucio.")
     dn = request.environ.get('SSL_CLIENT_S_DN')
     if not MULTI_VO:
-        ui_vo = 'def'
+        ui_vo = DEFAULT_VO
     elif hasattr(data, 'vo') and data.vo:
         ui_vo = data.vo
     else:
@@ -377,7 +381,7 @@ def userpass_auth():
         return render_template('problem.html', msg="No input credentials were provided.")
 
     if not MULTI_VO:
-        ui_vo = 'def'
+        ui_vo = DEFAULT_VO
     if ui_account is None and ui_vo is None:
         ui_account, ui_vo = select_account_name(username, 'userpass', ui_vo)
     elif ui_account is None:
@@ -427,12 +431,12 @@ def saml_auth(method, data=None):
     :param rendered_tpl: page to be rendered
     :returns: rendered final page or a page with error message
     """
-    SAML_PATH = join(dirname(__file__), 'saml/')
+    saml_path = join(dirname(__file__), 'saml/')
     req = prepare_saml_request(request.environ, data)
-    samlauth = OneLogin_Saml2_Auth(req, custom_base_path=SAML_PATH)
+    samlauth = OneLogin_Saml2_Auth(req, custom_base_path=saml_path)
     saml_user_data = request.cookies.get('saml-user-data')
     if not MULTI_VO:
-        ui_vo = 'def'
+        ui_vo = DEFAULT_VO
     elif hasattr(data, 'vo') and data.vo:
         ui_vo = data.vo
     else:
