@@ -26,7 +26,7 @@ import rucio.daemons.reaper.reaper
 from rucio.common.checksum import adler32
 from rucio.common.constants import RseAttr
 from rucio.common.exception import ReplicaNotFound, RequestNotFound
-from rucio.common.types import InternalAccount
+from rucio.common.types import FileToUploadDict, InternalAccount
 from rucio.common.utils import generate_uuid
 from rucio.core import config as core_config
 from rucio.core import did as did_core
@@ -41,15 +41,15 @@ from rucio.core.account_limit import set_local_account_limit
 from rucio.daemons.conveyor.finisher import finisher
 from rucio.daemons.conveyor.poller import poller
 from rucio.daemons.conveyor.preparer import preparer
-from rucio.daemons.conveyor.receiver import GRACEFUL_STOP as receiver_graceful_stop
+from rucio.daemons.conveyor.receiver import GRACEFUL_STOP as RECEIVER_GRACEFUL_STOP
 from rucio.daemons.conveyor.receiver import Receiver, receiver
 from rucio.daemons.conveyor.stager import stager
 from rucio.daemons.conveyor.submitter import submitter
 from rucio.daemons.conveyor.throttler import throttler
 from rucio.daemons.reaper.reaper import reaper
 from rucio.db.sqla import models
-from rucio.db.sqla.constants import LockState, ReplicaState, RequestState, RequestType, RSEType, RuleState
-from rucio.db.sqla.session import read_session, transactional_session
+from rucio.db.sqla.constants import DatabaseOperationType, LockState, ReplicaState, RequestState, RequestType, RSEType, RuleState
+from rucio.db.sqla.session import db_session
 from rucio.tests.common import skip_rse_tests_with_accounts
 from rucio.transfertool.fts3 import FTS3Transfertool
 from tests.mocks.mock_http_server import MockServer
@@ -59,8 +59,7 @@ MAX_POLL_WAIT_SECONDS = 100
 TEST_FTS_HOST = 'https://fts:8446'
 
 
-@transactional_session
-def __update_request(request_id, *, session=None, **kwargs):
+def __update_request(request_id, **kwargs):
     stmt = update(
         models.Request
     ).where(
@@ -70,7 +69,8 @@ def __update_request(request_id, *, session=None, **kwargs):
     ).values(
         kwargs
     )
-    session.execute(stmt)
+    with db_session(DatabaseOperationType.WRITE) as session:
+        session.execute(stmt)
 
 
 def __wait_for_replica_transfer(dst_rse_id, scope, name, max_wait_seconds=MAX_POLL_WAIT_SECONDS, transfertool=None):
@@ -127,8 +127,7 @@ def set_query_parameters(url, params):
     return urlunparse(url_parts)
 
 
-@read_session
-def __get_source(request_id, src_rse_id, scope, name, *, session=None):
+def __get_source(request_id, src_rse_id, scope, name):
     stmt = select(
         models.Source
     ).where(
@@ -137,7 +136,8 @@ def __get_source(request_id, src_rse_id, scope, name, *, session=None):
              models.Source.name == name,
              models.Source.rse_id == src_rse_id)
     )
-    return session.execute(stmt).scalar()
+    with db_session(DatabaseOperationType.READ) as session:
+        return session.execute(stmt).scalar()
 
 
 @pytest.fixture
@@ -213,18 +213,18 @@ def test_multihop_intermediate_replica_lifecycle(vo, did_factory, root_account,
         # Fake an existing unused source with raking of 0 for the second source.
         # The ranking of this source should remain at 0 till the end.
 
-        @transactional_session
-        def __fake_source_ranking(*, session=None):
-            models.Source(request_id=request['id'],
-                          scope=request['scope'],
-                          name=request['name'],
-                          rse_id=src_rse2_id,
-                          dest_rse_id=request['dest_rse_id'],
-                          ranking=0,
-                          bytes=request['bytes'],
-                          url=None,
-                          is_using=False). \
-                save(session=session, flush=False)
+        def __fake_source_ranking():
+            with db_session(DatabaseOperationType.WRITE) as session:
+                models.Source(request_id=request['id'],
+                              scope=request['scope'],
+                              name=request['name'],
+                              rse_id=src_rse2_id,
+                              dest_rse_id=request['dest_rse_id'],
+                              ranking=0,
+                              bytes=request['bytes'],
+                              url=None,
+                              is_using=False). \
+                    save(session=session, flush=False)
 
         __fake_source_ranking()
 
@@ -265,21 +265,22 @@ def test_multihop_intermediate_replica_lifecycle(vo, did_factory, root_account,
         assert metrics_mock.get_sample_value('rucio_daemons_conveyor_finisher_handle_requests_total') > 0
     finally:
 
-        @transactional_session
-        def _cleanup_all_usage_and_limits(rse_id, *, session=None):
+        def _cleanup_all_usage_and_limits(rse_id):
             stmt = delete(
                 models.RSELimit
             ).where(
                 models.RSELimit.rse_id == rse_id
             )
-            session.execute(stmt)
-            stmt = delete(
-                models.RSEUsage
-            ).where(
-                and_(models.RSEUsage.rse_id == rse_id,
-                     models.RSEUsage.source == 'storage')
-            )
-            session.execute(stmt)
+
+            with db_session(DatabaseOperationType.WRITE) as session:
+                session.execute(stmt)
+                stmt = delete(
+                    models.RSEUsage
+                ).where(
+                    and_(models.RSEUsage.rse_id == rse_id,
+                         models.RSEUsage.source == 'storage')
+                )
+                session.execute(stmt)
 
         _cleanup_all_usage_and_limits(rse_id=jump_rse_id)
 
@@ -302,7 +303,7 @@ def test_fts_non_recoverable_failures_handled_on_multihop(vo, did_factory, root_
 
     all_rses = [src_rse_id, jump_rse_id, dst_rse_id]
 
-    # Register a did which doesn't exist. It will trigger an non-recoverable error during the FTS transfer.
+    # Register a DID which doesn't exist. It will trigger a non-recoverable error during the FTS transfer.
     did = did_factory.random_file_did()
     replica_client.add_replicas(rse=src_rse, files=[{'scope': did['scope'].external, 'name': did['name'], 'bytes': 1, 'adler32': 'aaaaaaaa'}])
 
@@ -355,17 +356,16 @@ def test_fts_recoverable_failures_handled_on_multihop(vo, did_factory, root_acco
     # a FTS "Recoverable" failure on checksum validation
     local_file = file_factory.file_generator()
     did = did_factory.random_file_did()
-    did_factory.upload_client.upload(
-        [
-            {
-                'path': local_file,
-                'rse': src_rse,
-                'did_scope': did['scope'].external,
-                'did_name': did['name'],
-                'no_register': True,
-            }
-        ]
-    )
+
+    item: FileToUploadDict = {
+        'path': local_file,
+        'rse': src_rse,
+        'did_scope': did['scope'].external,
+        'did_name': did['name'],
+        'no_register': True,
+    }
+
+    did_factory.upload_client.upload(items=[item])
     replica_client.add_replicas(rse=src_rse, files=[{'scope': did['scope'].external, 'name': did['name'], 'bytes': 1, 'adler32': 'aaaaaaaa'}])
 
     rule_core.add_rule(dids=[did], account=root_account, copies=1, rse_expression=dst_rse, grouping='ALL', weight=None, lifetime=None, locked=False, subscription_id=None)
@@ -409,8 +409,7 @@ def test_multisource(vo, did_factory, root_account, replica_client, caches_mock,
     rule_core.add_rule(dids=[container], account=root_account, copies=1, rse_expression=dst_rse, grouping='ALL', weight=None, lifetime=None, locked=False, subscription_id=None)
     submitter(once=True, rses=[{'id': rse_id} for rse_id in all_rses], group_bulk=2, partition_wait_time=0, transfertype='single', filter_transfertool=None)
 
-    @read_session
-    def __source_exists(src_rse_id, scope, name, *, session=None):
+    def __source_exists(src_rse_id, scope, name):
         stmt = select(
             models.Source
         ).where(
@@ -418,7 +417,8 @@ def test_multisource(vo, did_factory, root_account, replica_client, caches_mock,
                  models.Source.scope == scope,
                  models.Source.name == name)
         )
-        return session.execute(stmt).scalar_one_or_none() is not None
+        with db_session(DatabaseOperationType.READ) as session:
+            return session.execute(stmt).scalar_one_or_none() is not None
 
     # Entries in the source table must be created for both sources of the multi-source transfer
     assert __source_exists(src_rse_id=src_rse1_id, **did)
@@ -452,6 +452,7 @@ def test_multisource(vo, did_factory, root_account, replica_client, caches_mock,
     )
 
 
+@pytest.mark.skip(reason="Pending https://cern.service-now.com/service-portal?id=ticket&table=incident&n=INC4506150")
 @skip_rse_tests_with_accounts
 @pytest.mark.dirty(reason="leaves files in XRD containers")
 @pytest.mark.noparallel(groups=[NoParallelGroups.XRD, NoParallelGroups.SUBMITTER, NoParallelGroups.RECEIVER])
@@ -520,11 +521,12 @@ def test_multisource_receiver(vo, did_factory, replica_client, root_account, met
         assert msg_done['payload']['dataset'] == dataset['name']
         assert msg_done['payload']['transfer_link'].startswith('https://fts:8449/')
     finally:
-        receiver_graceful_stop.set()
+        RECEIVER_GRACEFUL_STOP.set()
         receiver_thread.join(timeout=5)
-        receiver_graceful_stop.clear()
+        RECEIVER_GRACEFUL_STOP.clear()
 
 
+@pytest.mark.skip(reason="Pending https://cern.service-now.com/service-portal?id=ticket&table=incident&n=INC4506150")
 @skip_rse_tests_with_accounts
 @pytest.mark.noparallel(groups=[NoParallelGroups.XRD, NoParallelGroups.SUBMITTER, NoParallelGroups.RECEIVER])
 @pytest.mark.parametrize("caches_mock", [{"caches_to_mock": [
@@ -547,7 +549,7 @@ def test_multihop_receiver_on_failure(vo, did_factory, replica_client, root_acco
 
         all_rses = [src_rse_id, jump_rse_id, dst_rse_id]
 
-        # Register a did which doesn't exist. It will trigger a failure error during the FTS transfer.
+        # Register a DID which doesn't exist. It will trigger a failure error during the FTS transfer.
         did = did_factory.random_file_did()
         replica_client.add_replicas(rse=src_rse, files=[{'scope': did['scope'].external, 'name': did['name'], 'bytes': 1, 'adler32': 'aaaaaaaa'}])
 
@@ -574,11 +576,12 @@ def test_multihop_receiver_on_failure(vo, did_factory, replica_client, root_acco
         assert __get_source(request_id=request['id'], src_rse_id=src_rse_id, **did).ranking == -1
         assert request['state'] == RequestState.QUEUED
     finally:
-        receiver_graceful_stop.set()
+        RECEIVER_GRACEFUL_STOP.set()
         receiver_thread.join(timeout=5)
-        receiver_graceful_stop.clear()
+        RECEIVER_GRACEFUL_STOP.clear()
 
 
+@pytest.mark.skip(reason="Pending https://cern.service-now.com/service-portal?id=ticket&table=incident&n=INC4506150")
 @skip_rse_tests_with_accounts
 @pytest.mark.noparallel(groups=[NoParallelGroups.XRD, NoParallelGroups.SUBMITTER, NoParallelGroups.RECEIVER])
 @pytest.mark.parametrize("caches_mock", [{"caches_to_mock": [
@@ -618,11 +621,12 @@ def test_multihop_receiver_on_success(vo, did_factory, root_account, caches_mock
         # Two hops; both handled by receiver
         assert metrics_mock.get_sample_value('rucio_daemons_conveyor_receiver_update_request_state_total', labels={'updated': 'True'}) >= 2
     finally:
-        receiver_graceful_stop.set()
+        RECEIVER_GRACEFUL_STOP.set()
         receiver_thread.join(timeout=5)
-        receiver_graceful_stop.clear()
+        RECEIVER_GRACEFUL_STOP.clear()
 
 
+@pytest.mark.skip(reason="Pending https://cern.service-now.com/service-portal?id=ticket&table=incident&n=INC4506150")
 @skip_rse_tests_with_accounts
 @pytest.mark.dirty(reason="leaves files in XRD containers")
 @pytest.mark.noparallel(groups=[NoParallelGroups.XRD, NoParallelGroups.SUBMITTER, NoParallelGroups.RECEIVER, NoParallelGroups.POLLER])
@@ -687,11 +691,12 @@ def test_receiver_archiving(vo, did_factory, root_account, caches_mock, scitags_
             rse_core.update_rse(rse_id=dst_rse_id, parameters={'rse_type': RSEType.DISK})
             rse_core.del_rse_attribute(dst_rse_id, RseAttr.ARCHIVE_TIMEOUT)
 
-            receiver_graceful_stop.set()
+            RECEIVER_GRACEFUL_STOP.set()
             receiver_thread.join(timeout=5)
-            receiver_graceful_stop.clear()
+            RECEIVER_GRACEFUL_STOP.clear()
 
 
+@pytest.mark.skip(reason="Pending https://cern.service-now.com/service-portal?id=ticket&table=incident&n=INC4506150")
 @skip_rse_tests_with_accounts
 @pytest.mark.noparallel(groups=[NoParallelGroups.PREPARER, NoParallelGroups.THROTTLER, NoParallelGroups.SUBMITTER, NoParallelGroups.POLLER])
 @pytest.mark.parametrize("file_config_mock", [{
@@ -801,8 +806,7 @@ def test_preparer_throttler_submitter(rse_factory, did_factory, root_account, fi
     assert request4['state'] == RequestState.WAITING
 
     # Artificially set both requests' last_processed_at timestamp as >1 day old
-    @transactional_session
-    def __set_process_timestamp(request_ids, timestamp, *, session=None):
+    def __set_process_timestamp(request_ids, timestamp):
         stmt = update(
             models.Request
         ).where(
@@ -810,7 +814,9 @@ def test_preparer_throttler_submitter(rse_factory, did_factory, root_account, fi
         ).values({
             models.Request.last_processed_at: timestamp
         })
-        session.execute(stmt)
+
+        with db_session(DatabaseOperationType.WRITE) as session:
+            session.execute(stmt)
 
     __set_process_timestamp([request['id'] for request in [request3, request4]], datetime.utcnow() - timedelta(days=2))
 
@@ -1023,6 +1029,7 @@ def test_failed_transfers_to_mas_existing_replica(rse_factory, did_factory, root
     assert rule_core.get_rule(rule2_id)['state'] == RuleState.STUCK
 
 
+@pytest.mark.skip(reason="Pending https://cern.service-now.com/service-portal?id=ticket&table=incident&n=INC4506150")
 @skip_rse_tests_with_accounts
 @pytest.mark.noparallel(groups=[NoParallelGroups.SUBMITTER, NoParallelGroups.POLLER, NoParallelGroups.FINISHER])
 def test_lost_transfers(rse_factory, did_factory, root_account):
@@ -1121,7 +1128,7 @@ class FTSWrapper(FTS3Transfertool):
         self.on_submit(file)
         return file
 
-    def _FTS3Transfertool__bulk_query_responses(self, jobs_response, requests_by_eid):
+    def _FTS3Transfertool__bulk_query_responses(self, jobs_response, requests_by_eid):  # noqa: N802
         self.on_receive(jobs_response)
         return super()._FTS3Transfertool__bulk_query_responses(jobs_response, requests_by_eid)
 
@@ -1132,7 +1139,7 @@ def overwrite_on_tape_topology(rse_factory, did_factory, root_account, vo, file_
     Prepares the XRD* RSEs for an overwrite_on_tape test.
     - fakes that one xroot RSE is a tape destination (and rollbacks the change after the test)
 
-    Return a factory which allows to upload/register/add_rule for two dids
+    Return a factory which allows to upload/register/add_rule for two DIDs
     """
 
     rse1 = 'XRD1'
@@ -1151,17 +1158,16 @@ def overwrite_on_tape_topology(rse_factory, did_factory, root_account, vo, file_
         local_file = file_factory.file_generator()
         did = did_factory.random_file_did()
         did_factory.upload_test_file(src_rse, path=local_file, **did)
-        did_factory.upload_client.upload(
-            [
-                {
-                    'path': file_factory.file_generator(size=3) if simulate_dst_corrupted else local_file,
-                    'rse': dst_rse,
-                    'did_scope': did['scope'].external,
-                    'did_name': did['name'],
-                    'no_register': True,
-                }
-            ]
-        )
+
+        item: FileToUploadDict = {
+            'path': file_factory.file_generator(size=3) if simulate_dst_corrupted else local_file,
+            'rse': dst_rse,
+            'did_scope': did['scope'].external,
+            'did_name': did['name'],
+            'no_register': True,
+        }
+
+        did_factory.upload_client.upload(items=[item])
         return did
 
     def __create_dids(did1_corrupted=True, did2_corrupted=True):
@@ -1226,17 +1232,16 @@ def test_overwrite_hops(overwrite_on_tape_topology, caches_mock, did_factory, fi
     Ensure that we request overwrite of intermediate hops on multi-hop transfers towards TAPE RSEs
     """
     rse1_id, rse2_id, rse3_id, did1, did2 = overwrite_on_tape_topology(did1_corrupted=False, did2_corrupted=True)
-    did_factory.upload_client.upload(
-        [
-            {
-                'path': file_factory.file_generator(size=3),
-                'rse': rse_core.get_rse_name(rse2_id),
-                'did_scope': did1['scope'].external,
-                'did_name': did1['name'],
-                'no_register': True,
-            }
-        ]
-    )
+
+    item: FileToUploadDict = {
+            'path': file_factory.file_generator(size=3),
+            'rse': rse_core.get_rse_name(rse2_id),
+            'did_scope': did1['scope'].external,
+            'did_name': did1['name'],
+            'no_register': True,
+        }
+
+    did_factory.upload_client.upload(items=[item])
     all_rses = [rse1_id, rse2_id, rse3_id]
 
     submitter(once=True, rses=[{'id': rse_id} for rse_id in all_rses], group_bulk=10, partition_wait_time=0, transfertype='single', filter_transfertool=None)
@@ -1252,7 +1257,7 @@ def test_overwrite_hops(overwrite_on_tape_topology, caches_mock, did_factory, fi
     else:
         # FTS only recently introduced the overwrite_hops parameter. It will be ignored on old
         # fts versions and the first hop will fail with the  file exists error
-        # TODO: remove this else after FTS 3.12 release and after updating rucio/fts container with the new release
+        # TODO: remove this else after FTS 3.12 release and after updating rucio/test-fts container with the new release
         request = __wait_for_state_transition(dst_rse_id=rse2_id, **did1)
         assert request['state'] == RequestState.FAILED
         assert 'Destination file exists and overwrite is not enabled' in request['err_msg']
@@ -1425,6 +1430,7 @@ def test_multi_vo_certificates(file_config_mock, rse_factory, did_factory, scope
         assert sorted(certs_used_by_poller) == ['DEFAULT_DUMMY_CERT', 'NEW_VO_DUMMY_CERT']
 
 
+@pytest.mark.skip(reason="Pending https://cern.service-now.com/service-portal?id=ticket&table=incident&n=INC4506150")
 @skip_rse_tests_with_accounts
 @pytest.mark.noparallel(groups=[NoParallelGroups.SUBMITTER, NoParallelGroups.POLLER, NoParallelGroups.FINISHER])
 @pytest.mark.parametrize("core_config_mock", [
@@ -1556,6 +1562,7 @@ def test_two_multihops_same_intermediate_rse(rse_factory, did_factory, root_acco
     assert dict_stats[rse2_id][rse1_id]['bytes_done'] == 2
 
 
+@pytest.mark.skip(reason="Pending https://cern.service-now.com/service-portal?id=ticket&table=incident&n=INC4506150")
 @skip_rse_tests_with_accounts
 @pytest.mark.noparallel(groups=[NoParallelGroups.SUBMITTER, NoParallelGroups.POLLER])
 def test_checksum_validation(rse_factory, did_factory, root_account):
@@ -1608,6 +1615,7 @@ def test_checksum_validation(rse_factory, did_factory, root_account):
     assert request['state'] == RequestState.FAILED
 
 
+@pytest.mark.skip(reason="Pending https://cern.service-now.com/service-portal?id=ticket&table=incident&n=INC4506150")
 @skip_rse_tests_with_accounts
 @pytest.mark.noparallel(groups=[NoParallelGroups.XRD, NoParallelGroups.SUBMITTER, NoParallelGroups.RECEIVER])
 @pytest.mark.parametrize("file_config_mock", [
@@ -1650,9 +1658,9 @@ def test_transfer_with_tokens(vo, did_factory, root_account, caches_mock, file_c
                 time.sleep(1)
             assert received_messages[request['id']]['job_metadata']['auth_method'] == 'oauth2'
         finally:
-            receiver_graceful_stop.set()
+            RECEIVER_GRACEFUL_STOP.set()
             receiver_thread.join(timeout=5)
-            receiver_graceful_stop.clear()
+            RECEIVER_GRACEFUL_STOP.clear()
 
 
 @pytest.mark.noparallel(groups=[NoParallelGroups.PREPARER])
