@@ -30,9 +30,9 @@ from rucio.core import rse as rse_core
 from rucio.core import rule as rule_core
 from rucio.daemons.conveyor.submitter import submitter
 from rucio.daemons.reaper.reaper import reaper
-from rucio.db.sqla.constants import RequestState
+from rucio.db.sqla.constants import DatabaseOperationType, RequestState
 from rucio.db.sqla.models import Request, Source
-from rucio.db.sqla.session import read_session, transactional_session
+from rucio.db.sqla.session import db_session
 from tests.ruciopytest import NoParallelGroups
 
 
@@ -61,8 +61,7 @@ def test_request_submitted_in_order(rse_factory, did_factory, root_account):
         dids.append(did)
 
     # Forge request creation time to a random moment in the past hour
-    @transactional_session
-    def _forge_requests_creation_time(*, session=None):
+    def _forge_requests_creation_time():
         base_time = datetime.utcnow().replace(microsecond=0, minute=0) - timedelta(hours=1)
         assigned_times = set()
         for request in requests:
@@ -78,8 +77,9 @@ def test_request_submitted_in_order(rse_factory, did_factory, root_account):
             ).values({
                 Request.created_at: request_creation_time
             })
-            session.execute(stmt)
-            request['created_at'] = request_creation_time
+            with db_session(DatabaseOperationType.WRITE) as session:
+                session.execute(stmt)
+                request['created_at'] = request_creation_time
 
     _forge_requests_creation_time()
     requests = sorted(requests, key=lambda r: r['created_at'])
@@ -108,14 +108,14 @@ def test_skip_requests_from_expired_rules(rse_factory, did_factory, root_account
     distance_core.add_distance(src_rse_id, dst_rse_id, distance=10)
 
     did = did_factory.upload_test_file(rse_name=src_rse_name)
-    rule_core.add_rule(dids=[did],
-                       account=root_account,
-                       copies=1,
-                       rse_expression=dst_rse_name, grouping='ALL',
-                       weight=None,
-                       lifetime=-1,
-                       locked=False,
-                       subscription_id=None)[0]
+    rule = rule_core.add_rule(dids=[did],
+                              account=root_account,
+                              copies=1,
+                              rse_expression=dst_rse_name, grouping='ALL',
+                              weight=None,
+                              lifetime=-1,
+                              locked=False,
+                              subscription_id=None)[0]
     request = request_core.get_request_by_did(rse_id=dst_rse_id, **did)
     assert request_core.get_request(request_id=request['id'])['state'] == RequestState.QUEUED
 
@@ -125,6 +125,13 @@ def test_skip_requests_from_expired_rules(rse_factory, did_factory, root_account
               transfertype='single', filter_transfertool=None)
     assert request_core.get_request(request_id=request['id'])['state'] == RequestState.QUEUED
 
+    rule_core.move_rule(rule_id=rule, rse_expression=f'{dst_rse_name}&*')
+    submitter(once=True,
+              rses=[{'id': rse_id} for rse_id in (src_rse_id, dst_rse_id)],
+              partition_wait_time=None, transfertools=['mock'],
+              transfertype='single', filter_transfertool=None)
+    assert request_core.get_request(request_id=request['id'])['state'] == RequestState.SUBMITTED
+
 
 @pytest.mark.noparallel(groups=[NoParallelGroups.SUBMITTER])
 @pytest.mark.parametrize("core_config_mock", [
@@ -191,8 +198,7 @@ def test_multihop_sources_created(rse_factory, did_factory, root_account, core_c
     assert request
     assert request['source_rse_id'] == jump_rse3_id
 
-    @read_session
-    def __number_sources(rse_id, scope, name, *, session=None):
+    def __number_sources(rse_id, scope, name):
         stmt = select(
             func.count()
         ).select_from(
@@ -202,7 +208,8 @@ def test_multihop_sources_created(rse_factory, did_factory, root_account, core_c
                  Source.scope == scope,
                  Source.name == name)
         )
-        return session.execute(stmt).scalar()
+        with db_session(DatabaseOperationType.READ) as session:
+            return session.execute(stmt).scalar()
 
     # Ensure that sources where created for transfers
     for rse_id in [src_rse_id, jump_rse1_id, jump_rse2_id]:
@@ -273,8 +280,7 @@ def test_source_avoid_deletion(caches_mock, rse_factory, did_factory, root_accou
     replica = next(iter(replica_core.list_replicas(dids=[did], rse_expression=any_source)))
     assert len(replica['pfns']) == 2
 
-    @transactional_session
-    def __delete_sources(rse_id, scope, name, *, session=None):
+    def __delete_sources(rse_id, scope, name):
         stmt = delete(
             Source
         ).where(
@@ -282,7 +288,9 @@ def test_source_avoid_deletion(caches_mock, rse_factory, did_factory, root_accou
                  Source.scope == scope,
                  Source.name == name)
         )
-        session.execute(stmt)
+
+        with db_session(DatabaseOperationType.WRITE) as session:
+            session.execute(stmt)
 
     # Deletion succeeds for one replica (second still protected by existing request)
     __delete_sources(src_rse1_id, **did)
