@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import json
+import os
 import random
 import string
 from collections import namedtuple
@@ -25,7 +26,7 @@ from sqlalchemy import func, select
 import rucio.gateway.rule
 from rucio.client.ruleclient import RuleClient
 from rucio.common.config import config_get_bool
-from rucio.common.constants import RseAttr
+from rucio.common.constants import DEFAULT_VO, RseAttr
 from rucio.common.exception import (
     AccessDenied,
     DuplicateRule,
@@ -41,7 +42,6 @@ from rucio.common.exception import (
     RuleReplaceFailed,
     UnsupportedOperation,
 )
-from rucio.common.policy import get_policy
 from rucio.common.schema import get_schema_value
 from rucio.common.types import InternalAccount, InternalScope
 from rucio.common.utils import generate_uuid as uuid
@@ -59,8 +59,8 @@ from rucio.daemons.abacus.account import account_update
 from rucio.daemons.abacus.rse import rse_update
 from rucio.daemons.judge.evaluator import re_evaluator
 from rucio.db.sqla import models
-from rucio.db.sqla.constants import OBSOLETE, DIDType, LockState, RuleState
-from rucio.db.sqla.session import transactional_session
+from rucio.db.sqla.constants import OBSOLETE, DatabaseOperationType, DIDType, LockState, RuleState
+from rucio.db.sqla.session import db_session
 from rucio.gateway.account import add_account
 from rucio.tests.common import account_name_generator, did_name_generator, rse_name_generator
 from rucio.tests.common_server import get_vo
@@ -104,14 +104,13 @@ def tag_generator(size=8, chars=string.ascii_uppercase):
     return ''.join(random.choice(chars) for x in range(size))
 
 
-@transactional_session
-def check_dataset_ok_callback(scope, name, rse, rse_id, rule_id, *, session=None):
+def check_dataset_ok_callback(scope, name, rse, rse_id, rule_id):
     message = {'scope': scope.external,
                'name': name,
                'rse': rse,
                'rse_id': rse_id,
                'rule_id': rule_id}
-    if scope.vo != 'def':
+    if scope.vo != DEFAULT_VO:
         message['vo'] = scope.vo
 
     stmt = select(
@@ -121,16 +120,17 @@ def check_dataset_ok_callback(scope, name, rse, rse_id, rule_id, *, session=None
     ).where(
         models.Message.payload == json.dumps(message)
     )
-    return session.execute(stmt).scalar() > 0
+
+    with db_session(DatabaseOperationType.WRITE) as session:
+        return session.execute(stmt).scalar() > 0
 
 
-@transactional_session
-def check_rule_progress_callback(scope, name, progress, rule_id, *, session=None):
+def check_rule_progress_callback(scope, name, progress, rule_id):
     message = {'scope': scope.external,
                'name': name,
                'rule_id': rule_id,
                'progress': progress}
-    if scope.vo != 'def':
+    if scope.vo != DEFAULT_VO:
         message['vo'] = scope.vo
 
     stmt = select(
@@ -138,7 +138,9 @@ def check_rule_progress_callback(scope, name, progress, rule_id, *, session=None
     ).where(
         models.Message.payload == json.dumps(message)
     )
-    return session.execute(stmt).scalar_one_or_none() is not None
+
+    with db_session(DatabaseOperationType.WRITE) as session:
+        return session.execute(stmt).scalar_one_or_none() is not None
 
 
 @pytest.fixture
@@ -205,18 +207,18 @@ class TestCore:
         from dogpile.cache.api import NO_VALUE
 
         # create RSEs A, B, C (structured into namedtuples)
-        rseA, rseB, rseC = (
+        rse_a, rse_b, rse_c = (
             RSE_namedtuple(*rse_factory.make_mock_rse()) for _ in range(3)
         )
         rsekey, rseval = tag_generator(), tag_generator()
-        add_rse_attribute(rseA.id, rsekey, rseval)
+        add_rse_attribute(rse_a.id, rsekey, rseval)
 
         # create DID (dataset is easiest)
         dataset = did_factory.make_dataset()
 
         # create source replica expression
         if delete_rse:
-            source_replica_expression = rseA.name
+            source_replica_expression = rse_a.name
         else:
             source_replica_expression = f"{rsekey}={rseval}"
 
@@ -224,7 +226,7 @@ class TestCore:
         rule = {
             "account": root_account,
             "copies": 1,
-            "rse_expression": rseB.name,
+            "rse_expression": rse_b.name,
             "source_replica_expression": source_replica_expression
         }
         ruledict = add_rules([dataset], [rule])
@@ -232,16 +234,16 @@ class TestCore:
 
         # delete RSE-A (or otherwise unmatching from source replica expr)
         if delete_rse:
-            del_rse(rseA.id)
+            del_rse(rse_a.id)
         else:
-            del_rse_attribute(rseA.id, rsekey)
+            del_rse_attribute(rse_a.id, rsekey)
 
         # must remove cached entries for the Source Replica Expression
         caches_mock[0].set(sha256(source_replica_expression.encode()).hexdigest(), NO_VALUE)
 
         # move-rule asserts correct error
         with pytest.raises(InvalidSourceReplicaExpression):
-            move_rule(rule_id, rseC.name)
+            move_rule(rule_id, rse_c.name)
 
     def test_add_rule_to_file_ask_approval(self, vo, mock_scope, jdoe_account):
         """ REPLICATION RULE (CORE): Add a replication rule, asking approval"""
@@ -928,12 +930,9 @@ class TestCore:
             for filtered_lock in [lock for lock in get_replica_locks(scope=file['scope'], name=file['name'])]:
                 assert (filtered_lock['state'] == LockState.STUCK)
 
+    @pytest.mark.skipif(os.environ.get('POLICY') != 'atlas', reason='ATLAS-specific test')
     def test_delete_rule_country_admin(self, vo, mock_scope, did_factory, jdoe_account):
         """ REPLICATION RULE (CORE): Delete a rule with a country admin account"""
-        if get_policy() != 'atlas':
-            LOG.info("Skipping atlas-specific test")
-            return
-
         rse = rse_name_generator()
         rse_id = add_rse(rse, vo=vo)
         add_rse_attribute(rse_id, RseAttr.COUNTRY, 'test')
@@ -1024,12 +1023,9 @@ class TestCore:
         pytest.raises(RuleReplaceFailed, move_rule, rule_id, self.rse3)
         pytest.raises(RucioException, move_rule, 'foo', self.rse3)
 
+    @pytest.mark.skipif(os.environ.get('POLICY') != 'atlas', reason='ATLAS-specific test')
     def test_add_rule_with_scratchdisk(self, vo, mock_scope, did_factory, jdoe_account):
         """ REPLICATION RULE (CORE): Add a replication rule for scratchdisk"""
-        if get_policy() != 'atlas':
-            LOG.info("Skipping atlas-specific test")
-            return
-
         rse = rse_name_generator()
         rse_id = add_rse(rse, vo=vo)
         add_rse_attribute(rse_id, RseAttr.TYPE, 'SCRATCHDISK')
